using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.InputSystem;

public class PlayerController : MonoBehaviour
{
    public PlayerInputControl inputControl;
    public Vector2 inputDirection;

    private Rigidbody2D rb;
    private PhysicsCheck physicsCheck;
    private PlayerAnimation playerAnimation;

    [Header("")]
    public float speed;
    public float jumpForce;

    [Header("״̬")]
    public bool isDead;
    public bool isAttack;

    [Header("˷")]
    public bool isHurt;
    public float hurtForce;//

    [Header("")]
    public PhysicsMaterial2D Normal;
    public PhysicsMaterial2D Wall;
    private CapsuleCollider2D coll;

    private void Awake()
    {
        rb = GetComponent<Rigidbody2D>();
        physicsCheck = GetComponent<PhysicsCheck>();
        playerAnimation = GetComponent<PlayerAnimation>();
        coll = GetComponent<CapsuleCollider2D>();
        inputControl = new PlayerInputControl();
        //Ծ
        inputControl.GamePlayerInput.Jump.started += Jump;
        //
        inputControl.GamePlayerInput.Attack.started += PlayerAttack;
        
    }

    

    private void OnEnable()
    {
        inputControl.Enable();
    }

    private void OnDisable()
    {
        inputControl.Disable();
    }

    void Start()
    {
        
    }

    // Update is called once per frame
    void Update()
    {
        inputDirection = inputControl.GamePlayerInput.Move.ReadValue<Vector2>();
        CheckState();//л⻬⻬
    }

    private void FixedUpdate()
    {
        if(!isHurt && !isAttack)
        {
            Move();
        }
       
    }

    //ƶ
    public void Move()
    {
        
        rb.velocity = new Vector2(inputDirection.x*speed * Time.deltaTime, rb.velocity.y);
        //ת
        int faceDir = (int)transform.localScale.x;
        if(inputDirection.x > 0 )
        {
            faceDir = 1;
        }
        if (inputDirection.x < 0)
        {
            faceDir = -1;
        }

        transform.localScale = new Vector3(faceDir, transform.localScale.y, transform.localScale.z);
    }

    //Ծ
    private void Jump(InputAction.CallbackContext context)
    {
        if(physicsCheck.isGround)
        {
            rb.AddForce(transform.up * jumpForce, ForceMode2D.Impulse);
        }
    }

    //
    private void PlayerAttack(InputAction.CallbackContext context)
    {
        if (!physicsCheck.isGround)
        {
            return;
        }
        playerAnimation.PlayAttack();
        isAttack = true;
    }

    //˷
    public void GetHurt(Transform attacker)
    {
        isHurt = true;
        rb.velocity = Vector2.zero;
        Vector2 dir = new Vector2((transform.position.x - attacker.position.x),0).normalized;//һȡ1

        rb.AddForce(dir*hurtForce, ForceMode2D.Impulse);
    }


    //ͣһж
    public void PlayerDead()
    {
        isDead = true;
        inputControl.GamePlayerInput.Disable();
    }

    //л
    public void CheckState()
    {
        coll.sharedMaterial = physicsCheck.isGround ? Normal : Wall;
    }

}
